@@ -1,6 +1,6 @@
 {
 package Mite::App::Command;
-our $USES_MITE = 1;
+our $USES_MITE = q[Mite::Class];
 use strict;
 use warnings;
 
@@ -72,6 +72,18 @@ sub __META__ {
     };
 }
 
+sub DOES {
+    my ( $self, $role ) = @_;
+    our %DOES;
+    return $DOES{$role} if exists $DOES{$role};
+    return 1 if $role eq __PACKAGE__;
+    return $self->SUPER::DOES( $role );
+}
+
+sub does {
+    shift->DOES( @_ );
+}
+
 
 1;
 }
\ No newline at end of file
