@@ -6,7 +6,7 @@ package Mite::Attribute;
 use Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.002002';
+our $VERSION   = '0.002003';
 
 has class =>
   is            => rw,
@@ -70,7 +70,7 @@ has coerce =>
 
 has default =>
   is            => rw,
-  isa           => Maybe[Str|Ref],
+  isa           => Undef|Str|CodeRef|ScalarRef,
   predicate     => 'has_default';
 
 has lazy =>
@@ -262,25 +262,22 @@ sub _build_type {
     return $type;
 }
 
-sub has_dataref_default {
-    my $self = shift;
-
-    # We don't have a default
-    return 0 unless $self->has_default;
-
-    # It's not a reference.
-    return 0 if $self->has_simple_default;
-
-    return ref $self->default ne 'CODE';
-}
-
 sub has_coderef_default {
     my $self = shift;
 
     # We don't have a default
     return 0 unless $self->has_default;
 
-    return ref $self->default eq 'CODE';
+    return CodeRef->check( $self->default );
+}
+
+sub has_inline_default {
+    my $self = shift;
+
+    # We don't have a default
+    return 0 unless $self->has_default;
+
+    return ScalarRef->check( $self->default );
 }
 
 sub has_simple_default {
@@ -288,9 +285,6 @@ sub has_simple_default {
 
     return 0 unless $self->has_default;
 
-    # Special case for regular expressions, they do not need to be dumped.
-    return 1 if ref $self->default eq 'Regexp';
-
     return !ref $self->default;
 }
 
@@ -327,6 +321,9 @@ sub _compile_default {
         return sprintf 'do { my $method = %s; %s->$method }',
           $var, $selfvar;
     }
+    elsif ( $self->has_inline_default ) {
+        return ${ $self->default };
+    }
     elsif ( $self->has_simple_default ) {
         require B;
         return defined( $self->default ) ? B::perlstring( $self->default ) : 'undef';
